@@ -5,7 +5,7 @@ from pydantic import BaseModel, Field
 from pymongo.results import DeleteResult, UpdateResult
 
 from .mongo import Collection, Database
-from .utils import Q, processing_kwargs
+from .query import Q
 
 
 class Id(ObjectId):
@@ -57,8 +57,14 @@ class Document(BaseModel):
             return cls.__collection
 
     @classmethod
-    @processing_kwargs
-    def filter(cls, *args: Any, **kwargs: Any) -> list["Document"]:
+    def filter(
+        cls,
+        query: Q = Q(),
+        limit: int = 0,
+        skip: int = 0,
+        sort: Any = None,
+        **kwargs: Any
+    ) -> list["Document"]:
         """Get one or more documents from database.
 
         Works like `find` in pymongo.
@@ -73,11 +79,17 @@ class Document(BaseModel):
             list[`Document`]: Returns a `list` of documents, or empty `list`
             if no matching document is found.
         """
-        return [cls(**data) for data in cls.collection.find(kwargs)]
+        return [
+            cls(**data)
+            for data in cls.collection.find(
+                query, limit=limit, skip=skip, sort=sort, **kwargs
+            )
+        ]
 
     @classmethod
-    @processing_kwargs
-    def get(cls, *args: Any, **kwargs: Any) -> Union["Document", None]:
+    def get(
+        cls, query: Q, skip: int = 0, sort: Any = None, **kwargs: Any
+    ) -> Union["Document", None]:
         """Get a single document from the database.
 
         Works like `find_one` in pymongo.
@@ -92,22 +104,30 @@ class Document(BaseModel):
             Union[`Document`, `None`]: Returns a single document, or `None` if no matching
             document is found.
         """
-        obj = cls.collection.find_one(kwargs)
+        obj = cls.collection.find_one(query, sort=sort, skip=skip, **kwargs)
         return cls(**obj) if obj is not None else None
 
     @classmethod
-    def create(cls, *args: Any, **kwargs: Any) -> "Document":
+    def create(cls, **kwargs: Any) -> "Document":
         """Create document in the class collection.
 
         Returns:
             `Document`: Document model with `ObjectID` and included fields.
         """
-        obj = cls.collection.insert_one(kwargs).inserted_id
-        return cls(id=obj, **kwargs)
+        if not hasattr(cls, "_default_values"):
+            setattr(cls, "_default_values", {})
+            fields: dict = cls.__dict__["__fields__"]
+            for key, value in fields.items():
+                if value.default is not None:
+                    cls._default_values[key] = value.default
+        values: dict = getattr(cls, "_default_values")
+        values.update(kwargs)
+        obj = cls.collection.insert_one(values).inserted_id
+        return cls(_id=obj, **kwargs)
 
     @classmethod
     def create_many(
-        cls, *data: dict[str, Any], in_model=False, **kwargs
+        cls, *data: dict[str, Any], in_model=False
     ) -> list[Union[ObjectId, "Document"]]:
         """Create multiple documents in the class collection.
 
@@ -121,24 +141,22 @@ class Document(BaseModel):
         return [cls(id=_id, **values) for _id, values in zip(object_ids, data)]
 
     @classmethod
-    @processing_kwargs
-    def delete_one(cls, *args: Any, **kwargs: Any) -> DeleteResult:
+    def delete_one(cls, query: Q) -> DeleteResult:
         """Delete document in the class collection.
 
         Returns:
             DeleteResult: Delete result from Pymongo.
         """
-        return cls.collection.delete_one(kwargs)
+        return cls.collection.delete_one(query)
 
     @classmethod
-    @processing_kwargs
-    def delete_many(cls, *args: Any, **kwargs: Any) -> DeleteResult:
+    def delete_many(cls, query: Q = Q()) -> DeleteResult:
         """Delete multiple documents in the class collection.
 
         Returns:
             DeleteResult: Delete result from Pymongo.
         """
-        return cls.collection.delete_many(kwargs)
+        return cls.collection.delete_many(query)
 
     def delete(self) -> DeleteResult:
         """Delete instance.
@@ -161,7 +179,7 @@ class Document(BaseModel):
         )
 
     @classmethod
-    def update_one(cls, query: Q, *args: Any, **kwargs: Any) -> UpdateResult:
+    def update_one(cls, query: Q, **values: Any) -> UpdateResult:
         """Update document in the class collection.
 
         Args:
@@ -170,10 +188,10 @@ class Document(BaseModel):
         Returns:
             UpdateResult: Update result from Pymongo.
         """
-        return cls.collection.update_one(query, {"$set": kwargs})
+        return cls.collection.update_one(query, {"$set": values})
 
     @classmethod
-    def update_many(cls, query: Q, *args: Any, **kwargs: Any) -> UpdateResult:
+    def update_many(cls, query: Q = Q(), **values: Any) -> UpdateResult:
         """Update multiple documents in the class collection.
 
         Args:
@@ -182,9 +200,9 @@ class Document(BaseModel):
         Returns:
             UpdateResult: Update result from Pymongo.
         """
-        return cls.collection.update_many(query, {"$set": kwargs})
+        return cls.collection.update_many(query, {"$set": values})
 
-    def update(self, *args: Any, **kwargs: Any) -> UpdateResult:
+    def update(self, **values: Any) -> UpdateResult:
         """Update instance.
 
         Raises:
@@ -198,13 +216,13 @@ class Document(BaseModel):
                 "The object does not have an id,"
                 "set the lookup_field attribute to Meta"
             )
-        for key, value in kwargs.items():
+        for key, value in values.items():
             setattr(self, key, value)
         if ObjectId.is_valid(self.id):
-            return self.collection.update_one({"_id": self.id}, kwargs)
+            return self.collection.update_one({"_id": self.id}, values)
         lookup_field = self.Meta.lookup_field
         lookup_value = getattr(self, lookup_field)
-        return self.collection.update_one({lookup_field: lookup_value}, kwargs)
+        return self.collection.update_one({lookup_field: lookup_value}, values)
 
     class Meta:
         database: Database
