@@ -35,11 +35,3 @@ def modifier(key: str, value: Any) -> tuple[str, dict[str, Any]]:
     """
     key, suffix = key.split("__")
     return (key, {"$%s" % suffix: value})
-
-
-class Q(dict):
-    """Query object"""
-
-    @processing_kwargs
-    def __init__(self, **kwargs: Any) -> None:
-        self.update(kwargs)
